RadarAnimation class

RadarAnimation is a customizable widget that displays various radar sweep animations

Inheritance

Constructors

RadarAnimation({Key? key, double size = 200, Color sweepColor = Colors.green, Color backgroundColor = Colors.black, Duration duration = const Duration(seconds: 2), double sweepWidth = 2, bool showCircles = true, int numberOfCircles = 3, Color circleColor = Colors.green, RadarSweepStyle sweepStyle = RadarSweepStyle.line, RadarShape radarShape = RadarShape.circle, bool reverse = false, double dotSpacing = 15, double dotSize = 4, bool showCenterDot = true, Color centerDotColor = Colors.green, double centerDotSize = 6, List<Color>? gradientColors, bool pulseEffect = false, Duration? pulseDuration, double pulseScale = 1.2, bool fadeEdges = false, double fadeIntensity = 0.5})
const

Properties

backgroundColor Color
The background color of the radar animation.
final
centerDotColor Color
The color of the center dot in the radar animation.
final
centerDotSize double
The size of the center dot in the radar animation.
final
circleColor Color
The color of the circles in the radar animation.
final
dotSize double
The size of the dots in the dotted sweep style.
final
dotSpacing double
The spacing between dots in the dotted sweep style.
final
duration Duration
The duration of the radar animation.
final
fadeEdges bool
Whether to fade the edges of the sweep.
final
fadeIntensity double
The intensity of the fade effect.
final
gradientColors List<Color>?
The colors of the gradient in the gradient sweep style.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
numberOfCircles int
The number of circles to show in the radar animation.
final
pulseDuration Duration?
The duration of the pulse effect.
final
pulseEffect bool
Whether to apply a pulse effect to the radar animation.
final
pulseScale double
The scale of the pulse effect.
final
radarShape RadarShape
The shape of the radar.
final
reverse bool
Whether to reverse the direction of the sweep.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
showCenterDot bool
Whether to show a center dot in the radar animation.
final
showCircles bool
Whether to show circles in the radar animation.
final
size double
The size of the radar animation.
final
sweepColor Color
The color of the sweep in the radar animation.
final
sweepStyle RadarSweepStyle
The style of the sweep in the radar animation.
final
sweepWidth double
The width of the sweep in the radar animation.
final

Methods

createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() State<RadarAnimation>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited